@@ -42,18 +42,14 @@
 #include <QMimeData>
 
 #include <KActionCollection>
-#include <kio_version.h>
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
 #include <KIO/JobUiDelegateFactory>
-#else
-#include <KIO/JobUiDelegate>
-#endif
 #include <KIO/OpenUrlJob>
 #include <KIconDialog>
 #include <KIconLoader>
 #include <KLocalizedString>
 #include <KStandardAction>
 #include <QIcon>
+#include <kio_version.h>
 
 #include <QInputDialog>
 
@@ -288,8 +284,8 @@ void GlobalBookmarkManager::doExport(ExportType type, const QString &_path)
     // TODO - add a factory and make all this use the base class
     if (type == OperaExport) {
         if (path.isNull())
-            path = KOperaBookmarkImporterImpl().findDefaultLocation(true);
-        KOperaBookmarkExporterImpl exporter(mgr(), path);
+            path = OperaBookmarkImporterImpl().findDefaultLocation(true);
+        KOperaBookmarkExporterImpl exporter(path);
         exporter.write(mgr()->root());
         return;
 
@@ -302,8 +298,8 @@ void GlobalBookmarkManager::doExport(ExportType type, const QString &_path)
 
     } else if (type == IEExport) {
         if (path.isNull())
-            path = KIEBookmarkImporterImpl().findDefaultLocation(true);
-        KIEBookmarkExporterImpl exporter(mgr(), path);
+            path = IEBookmarkImporterImpl().findDefaultLocation(true);
+        IEBookmarkExporterImpl exporter(path);
         exporter.write(mgr()->root());
         return;
     }
@@ -315,13 +311,13 @@ void GlobalBookmarkManager::doExport(ExportType type, const QString &_path)
             KMozillaBookmarkImporterImpl importer;
             path = importer.findDefaultLocation(true);
         } else {
-            KNSBookmarkImporterImpl importer;
+            NSBookmarkImporterImpl importer;
             path = importer.findDefaultLocation(true);
         }
     }
 
     if (!path.isEmpty()) {
-        KNSBookmarkExporterImpl exporter(mgr(), path);
+        KNSBookmarkExporterImpl exporter(path);
         exporter.write(mgr()->root());
     }
 }
@@ -561,11 +557,7 @@ void ActionsImpl::slotOpenLink()
         }
 
         auto *job = new KIO::OpenUrlJob(bm.url());
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
         job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, KEBApp::self()));
-#else
-        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, KEBApp::self()));
-#endif
         job->start();
     }
 }
